@@ -31,7 +31,7 @@ class Middleware:
         return response
 
 
-class LogMiddleWare(Middleware):
+class LogMiddleware(Middleware):
     """
     A logger to help for debugging
     """
